@@ -128,29 +128,9 @@ format_variables_acs <- function(variables) {
 load_data_acs <- function(geography, formatted_variables, key, year, state = NULL,
                           county = NULL, survey, show_call = FALSE) {
 
-  # No longer necessary: see https://www.census.gov/content/dam/Census/data/developers/acs/acs-data-variables-guide.pdf
-  # if (survey == "acs1") {
-  #   if (year > 2014) {
-  #     survey <- "acs/acs1"
-  #   }
-  # }
-  #
-  # if (survey == "acs5" && year > 2014) {
-  #   survey <- "acs/acs5"
-  # }
-
-  if (year == 2009) {
-    # Only the old endpoint works right now for 2005-2009
-    base <- paste("https://api.census.gov/data",
-                  as.character(year),
-                  survey, sep = "/")
-  } else {
-    base <- paste("https://api.census.gov/data",
+  base <- paste("https://api.census.gov/data",
                   as.character(year), "acs",
                   survey, sep = "/")
-  }
-
-
 
   if (grepl("^DP", formatted_variables)) {
     message("Using the ACS Data Profile")
@@ -162,6 +142,8 @@ load_data_acs <- function(geography, formatted_variables, key, year, state = NUL
     base <- paste0(base, "/subject")
   }
 
+
+
   for_area <- paste0(geography, ":*")
 
   if (!is.null(state)) {
