@@ -48,10 +48,13 @@ moe_prop <- function(num, denom, moe_num, moe_denom) {
 
   prop <- num / denom
 
+  result <- moe_ratio(num = num, denom = denom, moe_num = moe_num, moe_denom = moe_denom)
+
   x <- moe_num^2 - (prop^2 * moe_denom^2)
 
-  result <- ifelse(x < 0, moe_ratio(num = num, denom = denom, moe_num = moe_num, moe_denom = moe_denom),
-                   sqrt(x) / denom)
+  pos_x <- x >= 0
+
+  result[pos_x] <- sqrt(x[pos_x]) / denom[pos_x]
 
   return(result)
 }
